.. _spkg_highspy:

highspy: Thin set of pybind11 wrappers to HiGHS
===============================================

Description
-----------

Thin set of pybind11 wrappers to HiGHS

License
-------

Upstream Contact
----------------

https://pypi.org/project/highspy/



Type
----

optional


Dependencies
------------

- $(PYTHON)
- $(PYTHON_TOOLCHAIN)
- :ref:`spkg_cmake`
- :ref:`spkg_highs`
- :ref:`spkg_ninja_build`
- :ref:`spkg_numpy`
- :ref:`spkg_pybind11`
- :ref:`spkg_scikit_build_core`

Version Information
-------------------

package-version.txt::

    1.13.0

version_requirements.txt::

    highspy

Installation commands
---------------------

.. tab:: PyPI:

   .. CODE-BLOCK:: bash

       $ pip install highspy

.. tab:: Sage distribution:

   .. CODE-BLOCK:: bash

       $ sage -i highspy


However, these system packages will not be used for building Sage
because ``spkg-configure.m4`` has not been written for this package;
see :issue:`27330` for more information.
